

<h3>Comment créer un formulaire XForm?</h3>
<ol>
    <li>Construire un fichier Excel avec 3 onglets: 'survey', 'choices', 'settings'<a href="#docxform" target="_blank"> Cfr. documentation ci-dessous</a></li>
    <li>Soumettre ce fichier sur <a href="https://getodk.org/xlsform/" target="_blank">https://getodk.org/xlsform/</a></li>
    <li>Vérifier que le formulaire fonctionne bien en cliquant sur 'Preview in browser'</li>
    <li>Télécharger le fichier XForm (fichier XML) sur votre ordinateur</li>
    <li>Charger ensuite ce fichier xml en cliquant sur 'Choose file'</li>
    <li>Cliquer sur 'Enregistrer'</li>
</ol>

