{% load i18n %}

<h4>{% blocktrans %}How to create an XLSForm?{% endblocktrans %}</h4>

<ol>
    <li>{% blocktrans %}Build an XLSForm file with 3 tabs 'survey', 'choices', 'settings' {% endblocktrans %}<a href="#docxform" target="_blank">Cfr documentation</a></li>
    <li>{% blocktrans %}Submit this file on {% endblocktrans %}<a href="https://getodk.org/xlsform/" target="_blank">https://getodk.org/xlsform/</a></li>
    <li>{% blocktrans %}Check file correctness while clicking on 'Preview in browser' button{% endblocktrans %}</li>
    <li>{% blocktrans %}Download the generated XForm file (XML file) on your computer{% endblocktrans %}</li>
    <li>{% blocktrans %}Load this xml file by clicking on 'Choose file'{% endblocktrans %}</li>
    <li>{% blocktrans %}Click on save button{% endblocktrans %}</li>
</ol>



<h4 id="docxform">Documentation</h4>

<p><a href="https://xlsform.org/en/" target="_blank">{% blocktrans %}What is an XLSForm?{% endblocktrans %}</a></p>

<p><a href="https://docs.getodk.org/xlsform/" target="_blank">{% blocktrans %}XLSForm Documentation{% endblocktrans %}</a></p>

<p><a href="https://docs.google.com/spreadsheets/d/1v9Bumt3R0vCOGEKQI6ExUf2-8T72-XXp_CbKKTACuko/edit#gid=0" target="_blank">
    {% blocktrans %}XLSForm example{% endblocktrans %}</a></p>

<p><a href="https://getodk.github.io/xforms-spec/" target="_blank">{% blocktrans %}ODK XForms Specifications{% endblocktrans %}</a></p>
